==> totoui-0.3.0.tgz: package/lib/close.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var Close = (function (_React$Component) {
    _inherits(Close, _React$Component);

    function Close(props) {
        _classCallCheck(this, Close);

        _get(Object.getPrototypeOf(Close.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
    }

    _createClass(Close, [{
        key: 'render',
        value: function render() {
            var Component = this.props.componentTag || 'button';
            var classSet = this.getClassSet();
            var props = this.props;

            // transfer type
            if (Component !== 'button') {
                props.type = undefined;
            }

            // className am-close-alt am-close-spin
            classSet[this.prefixClass('alt')] = this.props.alt;
            classSet[this.prefixClass('spin')] = this.props.spin;

            return _react2['default'].createElement(
                Component,
                _extends({}, props, {
                    className: (0, _classnames2['default'])(classSet, this.props.className),
                    role: "close" }),
                this.props.icon ? _react2['default'].createElement(_iconJsx2['default'], { icon: "times" }) : '×'
            );
        }
    }]);

    return Close;
})(_react2['default'].Component);

Close.displayName = "Close";

Close.propTypes = {
    classPrefix: _react2['default'].PropTypes.string.isRequired,
    componentTag: _react2['default'].PropTypes.node,
    spin: _react2['default'].PropTypes.bool,
    alt: _react2['default'].PropTypes.bool,
    icon: _react2['default'].PropTypes.bool
};

Close.defaultProps = {
    classPrefix: 'close',
    type: 'button'
};

module.exports = Close;

==> totoui-0.5.1.tgz: package/lib/close.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var Close = (function (_React$Component) {
    _inherits(Close, _React$Component);

    function Close(props) {
        _classCallCheck(this, Close);

        _get(Object.getPrototypeOf(Close.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
    }

    _createClass(Close, [{
        key: 'render',
        value: function render() {
            var Component = this.props.componentTag || 'button';
            var classSet = this.getClassSet();
            var props = this.props;

            // transfer type
            if (Component !== 'button') {
                props.type = undefined;
            }

            // className am-close-alt am-close-spin
            classSet[this.prefixClass('alt')] = this.props.alt;
            classSet[this.prefixClass('spin')] = this.props.spin;

            return _react2['default'].createElement(
                Component,
                _extends({}, props, {
                    className: (0, _classnames2['default'])(classSet, this.props.className),
                    role: 'close' }),
                this.props.icon ? _react2['default'].createElement(_iconJsx2['default'], { icon: 'times' }) : '×'
            );
        }
    }]);

    return Close;
})(_react2['default'].Component);

Close.displayName = "Close";

Close.propTypes = {
    classPrefix: _react2['default'].PropTypes.string.isRequired,
    componentTag: _react2['default'].PropTypes.node,
    spin: _react2['default'].PropTypes.bool,
    alt: _react2['default'].PropTypes.bool,
    icon: _react2['default'].PropTypes.bool
};

Close.defaultProps = {
    classPrefix: 'close',
    type: 'button'
};

module.exports = Close;
